@@ -1,6 +1,7 @@
 # Copyright Notice:
-# Copyright 2016-2019 DMTF. All rights reserved.
-# License: BSD 3-Clause License. For full text see link: https://github.com/DMTF/python-redfish-library/blob/master/LICENSE.md
+# Copyright 2016-2021 DMTF. All rights reserved.
+# License: BSD 3-Clause License. For full text see link:
+# https://github.com/DMTF/python-redfish-library/blob/master/LICENSE.md
 
 # -*- coding: utf-8 -*-
 """Helper module for working with REST technology."""
@@ -14,29 +15,18 @@ import time
 import gzip
 import json
 import base64
-import urllib
 import logging
-import inspect
+import http.client
+import re
 
 from collections import (OrderedDict)
 
-import six
-from six.moves.urllib.parse import urlparse, urlencode, urlunparse
-from six.moves import http_client
-from six import raise_from
-from six import string_types
-from six import StringIO
-from six import BytesIO
+from urllib.parse import urlparse, urlencode, quote
+from io import StringIO
+from io import BytesIO
 
 #---------End of imports---------
 
-#---------Python 3 support---------
-
-if sys.version_info > (3,):
-    buffer = memoryview
-
-#---------End of Python 3 support---------
-
 #---------Debug logger---------
 
 LOGGER = logging.getLogger(__name__)
@@ -313,7 +303,7 @@ class RestResponse(object):
             headerstr += '%s %s\n' % (header[0], header[1])
 
         return "%(status)s\n%(headerstr)s\n\n%(body)s" % \
-                            {'status': self.status, 'headerstr': headerstr, \
+                            {'status': self.status, 'headerstr': headerstr,
                              'body': self.text}
 
 class JSONEncoder(json.JSONEncoder):
@@ -381,7 +371,7 @@ class StaticRestResponse(RestResponse):
         if 'Content' in kwargs:
             content = kwargs['Content']
 
-            if isinstance(content, string_types):
+            if isinstance(content, str):
                 self._read = content
             else:
                 self._read = json.dumps(content)
@@ -457,7 +447,32 @@ class RestClientBase(object):
         self.__destroy_connection()
 
     @staticmethod
-    def _get_connection(url, **kwargs):
+    def _bypass_proxy(host):
+        """
+        Read NO_PROXY environment variable to determine if proxy should be
+        bypassed for host.
+
+        :param host: the host to check
+        :return: True is proxy should be bypassed, False otherwise
+        """
+        if 'NO_PROXY' in os.environ:
+            no_proxy = os.environ['NO_PROXY']
+            if no_proxy == '*':
+                return True
+            hostonly = host.rsplit(':', 1)[0]  # without port
+            no_proxy_list = [proxy.strip() for proxy in no_proxy.split(',')]
+            for name in no_proxy_list:
+                if name:
+                    name = name.lstrip('.')  # ignore leading dots
+                    name = re.escape(name)
+                    pattern = r'(.+\.)?%s$' % name
+                    if (re.match(pattern, hostonly, re.I)
+                            or re.match(pattern, host, re.I)):
+                        print('returning true (re)')
+                        return True
+        return False
+
+    def _get_connection(self, url, **kwargs):
         """
         Wrapper function for the HTTPSConnection/HTTPConnection constructor
         that handles proxies set by the HTTPS_PROXY and HTTP_PROXY environment
@@ -467,17 +482,18 @@ class RestClientBase(object):
         :param kwargs: keyword arguments for the connection constructor
         :return: the connection
         """
+        bypass_proxy = self._bypass_proxy(url.netloc)
         proxy = None
         if url.scheme.upper() == "HTTPS":
-            connection = http_client.HTTPSConnection
-            if 'HTTPS_PROXY' in os.environ:
+            connection = http.client.HTTPSConnection
+            if not bypass_proxy and 'HTTPS_PROXY' in os.environ:
                 host = urlparse(os.environ['HTTPS_PROXY']).netloc
                 proxy = url.netloc
             else:
                 host = url.netloc
         else:
-            connection = http_client.HTTPConnection
-            if 'HTTP_PROXY' in os.environ:
+            connection = http.client.HTTPConnection
+            if not bypass_proxy and 'HTTP_PROXY' in os.environ:
                 host = urlparse(os.environ['HTTP_PROXY']).netloc
                 proxy = url.netloc
             else:
@@ -500,17 +516,13 @@ class RestClientBase(object):
 
         url = url if url else self.__url
         if url.scheme.upper() == "HTTPS":
-            if sys.version_info < (2, 7, 9) and "context" not in inspect.getargspec(http_client.HTTPSConnection.__init__).args:
-                self._conn = self._get_connection(url, timeout=self._timeout)
+            if self.cafile or self.capath is not None:
+                ssl_context = ssl.create_default_context(capath=self.capath,
+                                                         cafile=self.cafile)
             else:
-                if self.cafile or self.capath is not None:
-                    ssl_context = ssl.create_default_context(
-                        capath=self.capath, cafile=self.cafile)
-                else:
-                    ssl_context = ssl._create_unverified_context()
-                self._conn = self._get_connection(url,
-                                                  context=ssl_context,
-                                                  timeout=self._timeout)
+                ssl_context = ssl._create_unverified_context()
+            self._conn = self._get_connection(url, context=ssl_context,
+                                              timeout=self._timeout)
         elif url.scheme.upper() == "HTTP":
             self._conn = self._get_connection(url, timeout=self._timeout)
         else:
@@ -639,14 +651,16 @@ class RestClientBase(object):
         """Perform a GET request
 
         :param path: the URL path.
-        :param path: str.
-        :params args: the arguments to get.
-        :params args: dict.
+        :type path: str.
+        :param args: the arguments to get.
+        :type args: dict.
+        :param headers: dict of headers to be appended.
+        :type headers: dict.
         :returns: returns a rest request with method 'Get'
 
         """
         try:
-            return self._rest_request(path, method='GET', args=args, \
+            return self._rest_request(path, method='GET', args=args,
                                                                 headers=headers)
         except ValueError:
             LOGGER.debug("Error in json object getting path: %s" % path)
@@ -656,22 +670,24 @@ class RestClientBase(object):
         """Perform a HEAD request
 
         :param path: the URL path.
-        :param path: str.
-        :params args: the arguments to get.
-        :params args: dict.
+        :type path: str.
+        :param args: the arguments to get.
+        :type args: dict.
+        :param headers: dict of headers to be appended.
+        :type headers: dict.
         :returns: returns a rest request with method 'Head'
 
         """
-        return self._rest_request(path, method='HEAD', args=args, \
+        return self._rest_request(path, method='HEAD', args=args,
                                                                 headers=headers)
 
     def post(self, path, args=None, body=None, headers=None):
         """Perform a POST request
 
         :param path: the URL path.
-        :param path: str.
-        :params args: the arguments to post.
-        :params args: dict.
+        :type path: str.
+        :param args: the arguments to post.
+        :type args: dict.
         :param body: the body to the sent.
         :type body: str.
         :param headers: dict of headers to be appended.
@@ -679,7 +695,7 @@ class RestClientBase(object):
         :returns: returns a rest request with method 'Post'
 
         """
-        return self._rest_request(path, method='POST', args=args, body=body, \
+        return self._rest_request(path, method='POST', args=args, body=body,
                                                                 headers=headers)
 
     def put(self, path, args=None, body=None, headers=None):
@@ -696,7 +712,7 @@ class RestClientBase(object):
         :returns: returns a rest request with method 'Put'
 
         """
-        return self._rest_request(path, method='PUT', args=args, body=body, \
+        return self._rest_request(path, method='PUT', args=args, body=body,
                                                                 headers=headers)
 
     def patch(self, path, args=None, body=None, headers=None):
@@ -713,7 +729,7 @@ class RestClientBase(object):
         :returns: returns a rest request with method 'Patch'
 
         """
-        return self._rest_request(path, method='PATCH', args=args, body=body, \
+        return self._rest_request(path, method='PATCH', args=args, body=body,
                                                                 headers=headers)
 
     def delete(self, path, args=None, headers=None):
@@ -728,7 +744,7 @@ class RestClientBase(object):
         :returns: returns a rest request with method 'Delete'
 
         """
-        return self._rest_request(path, method='DELETE', args=args, \
+        return self._rest_request(path, method='DELETE', args=args,
                                                                 headers=headers)
 
     def _get_req_headers(self, headers=None):
@@ -746,12 +762,15 @@ class RestClientBase(object):
         elif self.__authorization_key:
             headers['Authorization'] = self.__authorization_key
 
-        headers['Accept'] = '*/*'
+        headers_keys = set(k.lower() for k in headers)
+        if 'accept' not in headers_keys:
+            headers['Accept'] = '*/*'
+
         headers['Connection'] = 'Keep-Alive'
 
         return headers
 
-    def _rest_request(self, path, method='GET', args=None, body=None, \
+    def _rest_request(self, path, method='GET', args=None, body=None,
                                                                 headers=None):
         """Rest request main function
 
@@ -798,7 +817,7 @@ class RestClientBase(object):
                         compresseddata = buf.getvalue()
                         if compresseddata:
                             data = bytearray()
-                            data.extend(buffer(compresseddata))
+                            data.extend(memoryview(compresseddata))
                             body = data
                 except BaseException as excp:
                     LOGGER.error('Error occur while compressing body: %s', excp)
@@ -808,7 +827,20 @@ class RestClientBase(object):
 
         if args:
             if method == 'GET':
-                reqpath += '?' + urlencode(args)
+                # Workaround for this bug: https://bugs.python.org/issue18857
+                none_list = []
+                args_copy = {}
+                for query in args:
+                    if args[query] is None:
+                        none_list.append(query)
+                    else:
+                        args_copy[query] = args[query]
+                reqpath += '?' + urlencode(args_copy, quote_via=quote)
+                for query in none_list:
+                    if reqpath[-1] == '?':
+                        reqpath += query
+                    else:
+                        reqpath += '&' + query
             elif method == 'PUT' or method == 'POST' or method == 'PATCH':
                 LOGGER.warning('For POST, PUT and PATCH methods, the provided "args" parameter "{}" is ignored.'
                                .format(args))
@@ -842,7 +874,7 @@ class RestClientBase(object):
                     if self._conn is None:
                         self.__init_connection()
 
-                    self._conn.request(method.upper(), reqpath, body=body, \
+                    self._conn.request(method.upper(), reqpath, body=body,
                                                                 headers=headers)
                     self._conn_count += 1
 
@@ -855,17 +887,24 @@ class RestClientBase(object):
                         endtime = time.clock()
                     else:
                         endtime = time.perf_counter()
-                    LOGGER.info('Response Time to %s: %s seconds.'% \
-                                        (restreq.path, str(endtime-inittime)))
+                    LOGGER.info('Response Time for %s to %s: %s seconds.' %
+                                (method, reqpath, str(endtime-inittime)))
 
                     if resp.getheader('Connection') == 'close':
                         self.__destroy_connection()
+
+                    # redirect handling
                     if resp.status not in list(range(300, 399)) or \
                                                             resp.status == 304:
                         break
-
                     newloc = resp.getheader('location')
                     newurl = urlparse(newloc)
+                    if resp.status == 303:
+                        method = 'GET'
+                        body = None
+                        for h in ['Content-Type', 'Content-Length']:
+                            if h in headers:
+                                del headers[h]
 
                     reqpath = newurl.path
                     self.__init_connection(newurl)
@@ -878,7 +917,7 @@ class RestClientBase(object):
                         decompressedfile = gzip.GzipFile(fileobj=compressedfile)
                         restresp.text = decompressedfile.read().decode("utf-8")
                 except Exception as excp:
-                    LOGGER.error('Error occur while decompressing body: %s', \
+                    LOGGER.error('Error occur while decompressing body: %s',
                                                                         excp)
                     raise DecompressResponseError()
             except Exception as excp:
@@ -911,13 +950,13 @@ class RestClientBase(object):
                                 restresp._http_response.reason,
                                 headerstr, restresp.request.path, restresp.read))
                     except:
-                        LOGGER.debug('HTTP RESPONSE:\nCode:%s', (restresp))
+                        LOGGER.debug('HTTP RESPONSE:\nCode:%s', restresp)
                 else:
                     LOGGER.debug('HTTP RESPONSE: <No HTTP Response obtained>')
 
             return restresp
         else:
-            raise_from(RetriesExhaustedError(), cause_exception)
+            raise RetriesExhaustedError() from cause_exception
 
     def login(self, username=None, password=None, auth=AuthMethod.SESSION):
         """Login and start a REST session.  Remember to call logout() when"""
@@ -936,14 +975,14 @@ class RestClientBase(object):
         self.__password = password if password else self.__password
 
         if auth == AuthMethod.BASIC:
-            auth_key = base64.b64encode(('%s:%s' % (self.__username, \
+            auth_key = base64.b64encode(('%s:%s' % (self.__username,
                             self.__password)).encode('utf-8')).decode('utf-8')
             self.__authorization_key = 'Basic %s' % auth_key
 
             headers = dict()
             headers['Authorization'] = self.__authorization_key
 
-            respvalidate = self._rest_request('%s%s' % (self.__url.path, \
+            respvalidate = self._rest_request('%s%s' % (self.__url.path,
                                             self.login_url), headers=headers)
 
             if respvalidate.status == 401:
@@ -956,7 +995,7 @@ class RestClientBase(object):
             data['Password'] = self.__password
 
             headers = dict()
-            resp = self._rest_request(self.login_url, method="POST", \
+            resp = self._rest_request(self.login_url, method="POST",
                                                     body=data, headers=headers)
 
             LOGGER.info(json.loads('%s' % resp.text))
@@ -979,7 +1018,7 @@ class RestClientBase(object):
         """ Logout of session. YOU MUST CALL THIS WHEN YOU ARE DONE TO FREE"""
         """ UP SESSIONS"""
         if self.__session_key:
-            session_loc = self.__session_location.replace(self.__base_url, '')
+            session_loc = urlparse(self.__session_location).path
 
             resp = self.delete(session_loc)
             if resp.status not in [200, 202, 204]:
@@ -994,10 +1033,10 @@ class RestClientBase(object):
 
 class HttpClient(RestClientBase):
     """A client for Rest"""
-    def __init__(self, base_url, username=None, password=None, \
-                                default_prefix='/redfish/v1/', \
-                                sessionkey=None, capath=None, \
-                                cafile=None, timeout=None, \
+    def __init__(self, base_url, username=None, password=None,
+                                default_prefix='/redfish/v1/',
+                                sessionkey=None, capath=None,
+                                cafile=None, timeout=None,
                                 max_retry=None):
         """Initialize HttpClient
 
@@ -1021,10 +1060,10 @@ class HttpClient(RestClientBase):
         :type max_retry: int
 
         """
-        super(HttpClient, self).__init__(base_url, username=username, \
-                            password=password, default_prefix=default_prefix, \
-                            sessionkey=sessionkey, capath=capath, \
-                            cafile=cafile, timeout=timeout, \
+        super(HttpClient, self).__init__(base_url, username=username,
+                            password=password, default_prefix=default_prefix,
+                            sessionkey=sessionkey, capath=capath,
+                            cafile=cafile, timeout=timeout,
                             max_retry=max_retry)
 
         try:
@@ -1057,7 +1096,7 @@ class HttpClient(RestClientBase):
         else:
             pass
 
-        return super(HttpClient, self)._rest_request(path=path, method=method, \
+        return super(HttpClient, self)._rest_request(path=path, method=method,
                                          args=args, body=body, headers=headers)
 
     def _get_req_headers(self, headers=None, providerheader=None):
@@ -1069,14 +1108,16 @@ class HttpClient(RestClientBase):
 
         """
         headers = super(HttpClient, self)._get_req_headers(headers)
-        headers['OData-Version'] = '4.0'
+        headers_keys = set(k.lower() for k in headers)
+        if 'odata-version' not in headers_keys:
+            headers['OData-Version'] = '4.0'
 
         return headers
 
-def redfish_client(base_url=None, username=None, password=None, \
-                                default_prefix='/redfish/v1/', \
-                                sessionkey=None, capath=None, \
-                                cafile=None, timeout=None, \
+def redfish_client(base_url=None, username=None, password=None,
+                                default_prefix='/redfish/v1/',
+                                sessionkey=None, capath=None,
+                                cafile=None, timeout=None,
                                 max_retry=None):
     """Create and return appropriate REDFISH client instance."""
     """ Instantiates appropriate Redfish object based on existing"""
@@ -1103,7 +1144,7 @@ def redfish_client(base_url=None, username=None, password=None, \
     :returns: a client object.
 
     """
-    return HttpClient(base_url=base_url, username=username, password=password, \
-                        default_prefix=default_prefix, sessionkey=sessionkey, \
-                        capath=capath, cafile=cafile, timeout=timeout, \
+    return HttpClient(base_url=base_url, username=username, password=password,
+                        default_prefix=default_prefix, sessionkey=sessionkey,
+                        capath=capath, cafile=cafile, timeout=timeout,
                         max_retry=max_retry)
